Crate longbridge_httpcli

Crate longbridge_httpcli 

Longbridge OpenAPI HTTP client

Structs

HttpClient
Longbridge HTTP client
HttpClientConfig
Configuration options for Http client
HttpError
Represents an HTTP error
Json
A JSON payload
Method
The Request Method (VERB)
RequestBuilder
A request builder
SseEvent
An Event

Enums

AuthConfig
Authentication configuration
DcRegion
Data center region used for API gateway routing.
HttpClientError
Http client error type
QsError
Query string serialization error

Constants

DC_REGION_HEADER
HTTP and WebSocket header that selects the data center serving a request.

Traits

FromPayload
Represents a type that can parse from payload
ToPayload
Represents a type that can convert to payload

Functions

is_cn
Do the best to guess whether the access point is in China Mainland or not.

Type Aliases

HttpClientResult
Http client result type